X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/348469c284a35f66819c10819feff0ae91b5fde2..24c5243d0973b223e3813d299a5bde266c81b939:/samples/html/help/help.cpp?ds=sidebyside

diff --git a/samples/html/help/help.cpp b/samples/html/help/help.cpp
index 1f6448b31d..d54817fab5 100644
--- a/samples/html/help/help.cpp
+++ b/samples/html/help/help.cpp
@@ -16,7 +16,7 @@
 #endif
 
 // for all others, include the necessary headers (this file is usually all you
 // need because it includes almost all "standard" wxWindows headers
 #ifndef WX_PRECOMP
     #include "wx/wx.h"
 #endif
@@ -61,7 +61,7 @@
    private:
       wxHtmlHelpController help;
    
     // any class wishing to process wxWindows events must use this macro
     DECLARE_EVENT_TABLE()
    };
 
@@ -78,10 +78,10 @@
    };
 
 // ----------------------------------------------------------------------------
 // event tables and other macros for wxWindows
 // ----------------------------------------------------------------------------
 
 // the event tables connect the wxWindows events with the functions (event
 // handlers) which process them. It can be also done at run-time, but for the
 // simple menu events like this the static method is much simpler.
    BEGIN_EVENT_TABLE(MyFrame, wxFrame)
@@ -90,7 +90,7 @@
    EVT_CLOSE(MyFrame::OnClose)
    END_EVENT_TABLE()
 
    // Create a new application object: this macro will allow wxWindows to create
    // the application object during program execution (it's better than using a
    // static object for many reasons) and also declares the accessor function
    // wxGetApp() which will return the reference of the right type (i.e. MyApp and
@@ -111,12 +111,12 @@
 #if wxUSE_STREAMS && wxUSE_ZIPSTREAM && wxUSE_ZLIB 
       wxFileSystem::AddHandler(new wxZipFSHandler);
 #endif
-      SetVendorName(wxT("wxWindows"));
+      SetVendorName(wxT("wxWidgets"));
       SetAppName(wxT("wxHTMLHelp")); 
 
     // Create the main application window
       MyFrame *frame = new MyFrame(_("HTML Help Sample"),
-         wxPoint(50, 50), wxSize(150, 50));
+         wxDefaultPosition, wxDefaultSize);
 
     // Show it and tell the application that it's our main window
     // @@@ what does it do exactly, in fact? is it necessary here?
@@ -16,7 +16,7 @@
 
 // for all others, include the necessary headers (this file is usually all you
-// need because it includes almost all "standard" wxWindows headers
+// need because it includes almost all "standard" wxWidgets headers
 #ifndef WX_PRECOMP
     #include "wx/wx.h"
@@ -61,7 +61,7 @@
       wxHtmlHelpController help;
    
-    // any class wishing to process wxWindows events must use this macro
+    // any class wishing to process wxWidgets events must use this macro
     DECLARE_EVENT_TABLE()
    };
@@ -78,10 +78,10 @@
 
 // ----------------------------------------------------------------------------
-// event tables and other macros for wxWindows
+// event tables and other macros for wxWidgets
 // ----------------------------------------------------------------------------
 
@@ -78,10 +78,10 @@
 // ----------------------------------------------------------------------------
 
-// the event tables connect the wxWindows events with the functions (event
+// the event tables connect the wxWidgets events with the functions (event
 // handlers) which process them. It can be also done at run-time, but for the
 // simple menu events like this the static method is much simpler.
@@ -90,7 +90,7 @@
    END_EVENT_TABLE()
 
-   // Create a new application object: this macro will allow wxWindows to create
+   // Create a new application object: this macro will allow wxWidgets to create
    // the application object during program execution (it's better than using a
    // static object for many reasons) and also declares the accessor function